""" Contains all the data models used in inputs/outputs """

from .root_type_for_call_status import RootTypeForCallStatus
from .root_type_for_call_status_call_status import RootTypeForCallStatusCallStatus
from .root_type_for_json_cap_call_status import RootTypeForJSONCapCallStatus
from .root_type_for_json_cap_call_status_call_status import RootTypeForJSONCapCallStatusCallStatus
from .root_type_for_json_cap_call_status_call_status_status import RootTypeForJSONCapCallStatusCallStatusStatus
from .root_type_for_json_response_status import RootTypeForJSONResponseStatus
from .root_type_for_xml_cap_access_control import RootTypeForXMLCapAccessControl
from .root_type_for_xml_cap_access_control_access_control import RootTypeForXMLCapAccessControlAccessControl
from .root_type_for_xml_cap_access_control_access_control_employee_no_info import (
    RootTypeForXMLCapAccessControlAccessControlEmployeeNoInfo,
)
from .root_type_for_xml_cap_access_control_access_control_employee_no_info_character_type import (
    RootTypeForXMLCapAccessControlAccessControlEmployeeNoInfoCharacterType,
)
from .root_type_for_xml_cap_access_control_access_control_employee_no_info_employee_no import (
    RootTypeForXMLCapAccessControlAccessControlEmployeeNoInfoEmployeeNo,
)
from .root_type_for_xml_cap_access_control_access_control_employee_no_info_is_support_compress import (
    RootTypeForXMLCapAccessControlAccessControlEmployeeNoInfoIsSupportCompress,
)
from .root_type_for_xml_cap_access_control_access_control_factory_reset import (
    RootTypeForXMLCapAccessControlAccessControlFactoryReset,
)
from .root_type_for_xml_cap_access_control_access_control_factory_reset_mode import (
    RootTypeForXMLCapAccessControlAccessControlFactoryResetMode,
)
from .root_type_for_xml_cap_access_control_access_control_is_support_acs_cfg import (
    RootTypeForXMLCapAccessControlAccessControlIsSupportAcsCfg,
)
from .root_type_for_xml_cap_access_control_access_control_is_support_acs_event import (
    RootTypeForXMLCapAccessControlAccessControlIsSupportAcsEvent,
)
from .root_type_for_xml_cap_access_control_access_control_is_support_acs_event_total_num import (
    RootTypeForXMLCapAccessControlAccessControlIsSupportAcsEventTotalNum,
)
from .root_type_for_xml_cap_access_control_access_control_is_support_acs_work_status import (
    RootTypeForXMLCapAccessControlAccessControlIsSupportAcsWorkStatus,
)
from .root_type_for_xml_cap_access_control_access_control_is_support_anti_sneak_cfg import (
    RootTypeForXMLCapAccessControlAccessControlIsSupportAntiSneakCfg,
)
from .root_type_for_xml_cap_access_control_access_control_is_support_attendance_holiday_group import (
    RootTypeForXMLCapAccessControlAccessControlIsSupportAttendanceHolidayGroup,
)
from .root_type_for_xml_cap_access_control_access_control_is_support_attendance_holiday_plan import (
    RootTypeForXMLCapAccessControlAccessControlIsSupportAttendanceHolidayPlan,
)
from .root_type_for_xml_cap_access_control_access_control_is_support_attendance_rule import (
    RootTypeForXMLCapAccessControlAccessControlIsSupportAttendanceRule,
)
from .root_type_for_xml_cap_access_control_access_control_is_support_attendance_status_mode_cfg import (
    RootTypeForXMLCapAccessControlAccessControlIsSupportAttendanceStatusModeCfg,
)
from .root_type_for_xml_cap_access_control_access_control_is_support_attendance_status_rule_cfg import (
    RootTypeForXMLCapAccessControlAccessControlIsSupportAttendanceStatusRuleCfg,
)
from .root_type_for_xml_cap_access_control_access_control_is_support_auth_code_info import (
    RootTypeForXMLCapAccessControlAccessControlIsSupportAuthCodeInfo,
)
from .root_type_for_xml_cap_access_control_access_control_is_support_capture_card_info import (
    RootTypeForXMLCapAccessControlAccessControlIsSupportCaptureCardInfo,
)
from .root_type_for_xml_cap_access_control_access_control_is_support_capture_face import (
    RootTypeForXMLCapAccessControlAccessControlIsSupportCaptureFace,
)
from .root_type_for_xml_cap_access_control_access_control_is_support_capture_finger_print import (
    RootTypeForXMLCapAccessControlAccessControlIsSupportCaptureFingerPrint,
)
from .root_type_for_xml_cap_access_control_access_control_is_support_capture_id_info import (
    RootTypeForXMLCapAccessControlAccessControlIsSupportCaptureIDInfo,
)
from .root_type_for_xml_cap_access_control_access_control_is_support_capture_infrared_face import (
    RootTypeForXMLCapAccessControlAccessControlIsSupportCaptureInfraredFace,
)
from .root_type_for_xml_cap_access_control_access_control_is_support_capture_preset_param import (
    RootTypeForXMLCapAccessControlAccessControlIsSupportCapturePresetParam,
)
from .root_type_for_xml_cap_access_control_access_control_is_support_capture_rule import (
    RootTypeForXMLCapAccessControlAccessControlIsSupportCaptureRule,
)
from .root_type_for_xml_cap_access_control_access_control_is_support_card_operations import (
    RootTypeForXMLCapAccessControlAccessControlIsSupportCardOperations,
)
from .root_type_for_xml_cap_access_control_access_control_is_support_card_reader_anti_sneak_cfg import (
    RootTypeForXMLCapAccessControlAccessControlIsSupportCardReaderAntiSneakCfg,
)
from .root_type_for_xml_cap_access_control_access_control_is_support_card_reader_cfg import (
    RootTypeForXMLCapAccessControlAccessControlIsSupportCardReaderCfg,
)
from .root_type_for_xml_cap_access_control_access_control_is_support_card_reader_plan import (
    RootTypeForXMLCapAccessControlAccessControlIsSupportCardReaderPlan,
)
from .root_type_for_xml_cap_access_control_access_control_is_support_card_right_holiday_plan_cfg import (
    RootTypeForXMLCapAccessControlAccessControlIsSupportCardRightHolidayPlanCfg,
)
from .root_type_for_xml_cap_access_control_access_control_is_support_card_right_week_plan_cfg import (
    RootTypeForXMLCapAccessControlAccessControlIsSupportCardRightWeekPlanCfg,
)
from .root_type_for_xml_cap_access_control_access_control_is_support_channel_controller_alarm_linkage import (
    RootTypeForXMLCapAccessControlAccessControlIsSupportChannelControllerAlarmLinkage,
)
from .root_type_for_xml_cap_access_control_access_control_is_support_channel_controller_alarm_out import (
    RootTypeForXMLCapAccessControlAccessControlIsSupportChannelControllerAlarmOut,
)
from .root_type_for_xml_cap_access_control_access_control_is_support_channel_controller_alarm_out_control import (
    RootTypeForXMLCapAccessControlAccessControlIsSupportChannelControllerAlarmOutControl,
)
from .root_type_for_xml_cap_access_control_access_control_is_support_channel_controller_cfg import (
    RootTypeForXMLCapAccessControlAccessControlIsSupportChannelControllerCfg,
)
from .root_type_for_xml_cap_access_control_access_control_is_support_channel_controller_type_cfg import (
    RootTypeForXMLCapAccessControlAccessControlIsSupportChannelControllerTypeCfg,
)
from .root_type_for_xml_cap_access_control_access_control_is_support_clear_anti_sneak import (
    RootTypeForXMLCapAccessControlAccessControlIsSupportClearAntiSneak,
)
from .root_type_for_xml_cap_access_control_access_control_is_support_clear_anti_sneak_cfg import (
    RootTypeForXMLCapAccessControlAccessControlIsSupportClearAntiSneakCfg,
)
from .root_type_for_xml_cap_access_control_access_control_is_support_clear_card_record import (
    RootTypeForXMLCapAccessControlAccessControlIsSupportClearCardRecord,
)
from .root_type_for_xml_cap_access_control_access_control_is_support_clear_event_card_linkage_cfg import (
    RootTypeForXMLCapAccessControlAccessControlIsSupportClearEventCardLinkageCfg,
)
from .root_type_for_xml_cap_access_control_access_control_is_support_clear_group_cfg import (
    RootTypeForXMLCapAccessControlAccessControlIsSupportClearGroupCfg,
)
from .root_type_for_xml_cap_access_control_access_control_is_support_clear_plans_cfg import (
    RootTypeForXMLCapAccessControlAccessControlIsSupportClearPlansCfg,
)
from .root_type_for_xml_cap_access_control_access_control_is_support_clear_submarine_back import (
    RootTypeForXMLCapAccessControlAccessControlIsSupportClearSubmarineBack,
)
from .root_type_for_xml_cap_access_control_access_control_is_support_department_param import (
    RootTypeForXMLCapAccessControlAccessControlIsSupportDepartmentParam,
)
from .root_type_for_xml_cap_access_control_access_control_is_support_deploy_info_item import (
    RootTypeForXMLCapAccessControlAccessControlIsSupportDeployInfoItem,
)
from .root_type_for_xml_cap_access_control_access_control_is_support_door_cfg import (
    RootTypeForXMLCapAccessControlAccessControlIsSupportDoorCfg,
)
from .root_type_for_xml_cap_access_control_access_control_is_support_door_status_holiday_group_cfg import (
    RootTypeForXMLCapAccessControlAccessControlIsSupportDoorStatusHolidayGroupCfg,
)
from .root_type_for_xml_cap_access_control_access_control_is_support_door_status_holiday_plan_cfg import (
    RootTypeForXMLCapAccessControlAccessControlIsSupportDoorStatusHolidayPlanCfg,
)
from .root_type_for_xml_cap_access_control_access_control_is_support_door_status_plan import (
    RootTypeForXMLCapAccessControlAccessControlIsSupportDoorStatusPlan,
)
from .root_type_for_xml_cap_access_control_access_control_is_support_door_status_plan_template import (
    RootTypeForXMLCapAccessControlAccessControlIsSupportDoorStatusPlanTemplate,
)
from .root_type_for_xml_cap_access_control_access_control_is_support_door_status_week_plan_cfg import (
    RootTypeForXMLCapAccessControlAccessControlIsSupportDoorStatusWeekPlanCfg,
)
from .root_type_for_xml_cap_access_control_access_control_is_support_event_card_linkage_cfg import (
    RootTypeForXMLCapAccessControlAccessControlIsSupportEventCardLinkageCfg,
)
from .root_type_for_xml_cap_access_control_access_control_is_support_event_card_no_list import (
    RootTypeForXMLCapAccessControlAccessControlIsSupportEventCardNoList,
)
from .root_type_for_xml_cap_access_control_access_control_is_support_event_optimization_cfg import (
    RootTypeForXMLCapAccessControlAccessControlIsSupportEventOptimizationCfg,
)
from .root_type_for_xml_cap_access_control_access_control_is_support_face_recognize_mode import (
    RootTypeForXMLCapAccessControlAccessControlIsSupportFaceRecognizeMode,
)
from .root_type_for_xml_cap_access_control_access_control_is_support_finger_print_cfg import (
    RootTypeForXMLCapAccessControlAccessControlIsSupportFingerPrintCfg,
)
from .root_type_for_xml_cap_access_control_access_control_is_support_finger_print_delete import (
    RootTypeForXMLCapAccessControlAccessControlIsSupportFingerPrintDelete,
)
from .root_type_for_xml_cap_access_control_access_control_is_support_gate_dial_and_info import (
    RootTypeForXMLCapAccessControlAccessControlIsSupportGateDialAndInfo,
)
from .root_type_for_xml_cap_access_control_access_control_is_support_gate_ir_status import (
    RootTypeForXMLCapAccessControlAccessControlIsSupportGateIRStatus,
)
from .root_type_for_xml_cap_access_control_access_control_is_support_gate_related_parts_status import (
    RootTypeForXMLCapAccessControlAccessControlIsSupportGateRelatedPartsStatus,
)
from .root_type_for_xml_cap_access_control_access_control_is_support_gate_status import (
    RootTypeForXMLCapAccessControlAccessControlIsSupportGateStatus,
)
from .root_type_for_xml_cap_access_control_access_control_is_support_group_cfg import (
    RootTypeForXMLCapAccessControlAccessControlIsSupportGroupCfg,
)
from .root_type_for_xml_cap_access_control_access_control_is_support_identity_terminal import (
    RootTypeForXMLCapAccessControlAccessControlIsSupportIdentityTerminal,
)
from .root_type_for_xml_cap_access_control_access_control_is_support_ladder_control_relay import (
    RootTypeForXMLCapAccessControlAccessControlIsSupportLadderControlRelay,
)
from .root_type_for_xml_cap_access_control_access_control_is_support_log_mode_cfg import (
    RootTypeForXMLCapAccessControlAccessControlIsSupportLogModeCfg,
)
from .root_type_for_xml_cap_access_control_access_control_is_support_m1_card_encrypt_cfg import (
    RootTypeForXMLCapAccessControlAccessControlIsSupportM1CardEncryptCfg,
)
from .root_type_for_xml_cap_access_control_access_control_is_support_module_status import (
    RootTypeForXMLCapAccessControlAccessControlIsSupportModuleStatus,
)
from .root_type_for_xml_cap_access_control_access_control_is_support_multi_card_cfg import (
    RootTypeForXMLCapAccessControlAccessControlIsSupportMultiCardCfg,
)
from .root_type_for_xml_cap_access_control_access_control_is_support_multi_door_inter_lock_cfg import (
    RootTypeForXMLCapAccessControlAccessControlIsSupportMultiDoorInterLockCfg,
)
from .root_type_for_xml_cap_access_control_access_control_is_support_offline_capture import (
    RootTypeForXMLCapAccessControlAccessControlIsSupportOfflineCapture,
)
from .root_type_for_xml_cap_access_control_access_control_is_support_ordinary_class import (
    RootTypeForXMLCapAccessControlAccessControlIsSupportOrdinaryClass,
)
from .root_type_for_xml_cap_access_control_access_control_is_support_osdp_modify import (
    RootTypeForXMLCapAccessControlAccessControlIsSupportOSDPModify,
)
from .root_type_for_xml_cap_access_control_access_control_is_support_osdp_status import (
    RootTypeForXMLCapAccessControlAccessControlIsSupportOSDPStatus,
)
from .root_type_for_xml_cap_access_control_access_control_is_support_phone_door_right_cfg import (
    RootTypeForXMLCapAccessControlAccessControlIsSupportPhoneDoorRightCfg,
)
from .root_type_for_xml_cap_access_control_access_control_is_support_reader_across_host import (
    RootTypeForXMLCapAccessControlAccessControlIsSupportReaderAcrossHost,
)
from .root_type_for_xml_cap_access_control_access_control_is_support_remote_control_buzzer import (
    RootTypeForXMLCapAccessControlAccessControlIsSupportRemoteControlBuzzer,
)
from .root_type_for_xml_cap_access_control_access_control_is_support_remote_control_door import (
    RootTypeForXMLCapAccessControlAccessControlIsSupportRemoteControlDoor,
)
from .root_type_for_xml_cap_access_control_access_control_is_support_remote_control_pw_cfg import (
    RootTypeForXMLCapAccessControlAccessControlIsSupportRemoteControlPWCfg,
)
from .root_type_for_xml_cap_access_control_access_control_is_support_remote_control_pw_chcek import (
    RootTypeForXMLCapAccessControlAccessControlIsSupportRemoteControlPWChcek,
)
from .root_type_for_xml_cap_access_control_access_control_is_support_right_controller_audio import (
    RootTypeForXMLCapAccessControlAccessControlIsSupportRightControllerAudio,
)
from .root_type_for_xml_cap_access_control_access_control_is_support_schedule_plan import (
    RootTypeForXMLCapAccessControlAccessControlIsSupportSchedulePlan,
)
from .root_type_for_xml_cap_access_control_access_control_is_support_server_device import (
    RootTypeForXMLCapAccessControlAccessControlIsSupportServerDevice,
)
from .root_type_for_xml_cap_access_control_access_control_is_support_sms_relative_param import (
    RootTypeForXMLCapAccessControlAccessControlIsSupportSmsRelativeParam,
)
from .root_type_for_xml_cap_access_control_access_control_is_support_snap_config import (
    RootTypeForXMLCapAccessControlAccessControlIsSupportSNAPConfig,
)
from .root_type_for_xml_cap_access_control_access_control_is_support_start_reader_info import (
    RootTypeForXMLCapAccessControlAccessControlIsSupportStartReaderInfo,
)
from .root_type_for_xml_cap_access_control_access_control_is_support_submarine_back import (
    RootTypeForXMLCapAccessControlAccessControlIsSupportSubmarineBack,
)
from .root_type_for_xml_cap_access_control_access_control_is_support_submarine_back_host_info import (
    RootTypeForXMLCapAccessControlAccessControlIsSupportSubmarineBackHostInfo,
)
from .root_type_for_xml_cap_access_control_access_control_is_support_submarine_back_mode import (
    RootTypeForXMLCapAccessControlAccessControlIsSupportSubmarineBackMode,
)
from .root_type_for_xml_cap_access_control_access_control_is_support_submarine_back_reader import (
    RootTypeForXMLCapAccessControlAccessControlIsSupportSubmarineBackReader,
)
from .root_type_for_xml_cap_access_control_access_control_is_support_usb_manage import (
    RootTypeForXMLCapAccessControlAccessControlIsSupportUSBManage,
)
from .root_type_for_xml_cap_access_control_access_control_is_support_user_right_holiday_group_cfg import (
    RootTypeForXMLCapAccessControlAccessControlIsSupportUserRightHolidayGroupCfg,
)
from .root_type_for_xml_cap_access_control_access_control_is_support_user_right_plan_template import (
    RootTypeForXMLCapAccessControlAccessControlIsSupportUserRightPlanTemplate,
)
from .root_type_for_xml_cap_access_control_access_control_is_support_verify_holiday_group_cfg import (
    RootTypeForXMLCapAccessControlAccessControlIsSupportVerifyHolidayGroupCfg,
)
from .root_type_for_xml_cap_access_control_access_control_is_support_verify_holiday_plan_cfg import (
    RootTypeForXMLCapAccessControlAccessControlIsSupportVerifyHolidayPlanCfg,
)
from .root_type_for_xml_cap_access_control_access_control_is_support_verify_plan_template import (
    RootTypeForXMLCapAccessControlAccessControlIsSupportVerifyPlanTemplate,
)
from .root_type_for_xml_cap_access_control_access_control_is_support_verify_week_plan_cfg import (
    RootTypeForXMLCapAccessControlAccessControlIsSupportVerifyWeekPlanCfg,
)
from .root_type_for_xml_cap_access_control_access_control_is_support_wiegand_cfg import (
    RootTypeForXMLCapAccessControlAccessControlIsSupportWiegandCfg,
)
from .root_type_for_xml_cap_access_control_access_control_is_support_wiegand_rule_cfg import (
    RootTypeForXMLCapAccessControlAccessControlIsSupportWiegandRuleCfg,
)
from .root_type_for_xml_cap_access_control_access_control_is_support_working_class import (
    RootTypeForXMLCapAccessControlAccessControlIsSupportWorkingClass,
)
from .root_type_for_xml_cap_access_control_access_control_local_controller import (
    RootTypeForXMLCapAccessControlAccessControlLocalController,
)
from .root_type_for_xml_cap_access_control_access_control_local_controller_is_support_local_controller_control import (
    RootTypeForXMLCapAccessControlAccessControlLocalControllerIsSupportLocalControllerControl,
)
from .root_type_for_xml_cap_access_control_access_control_local_controller_is_support_local_controller_manage import (
    RootTypeForXMLCapAccessControlAccessControlLocalControllerIsSupportLocalControllerManage,
)
from .root_type_for_xml_cap_remote_control_door import RootTypeForXMLCapRemoteControlDoor
from .root_type_for_xml_cap_remote_control_door_remote_control_door import (
    RootTypeForXMLCapRemoteControlDoorRemoteControlDoor,
)
from .root_type_for_xml_cap_remote_control_door_remote_control_door_cmd import (
    RootTypeForXMLCapRemoteControlDoorRemoteControlDoorCmd,
)
from .root_type_for_xml_cap_remote_control_door_remote_control_door_door_no import (
    RootTypeForXMLCapRemoteControlDoorRemoteControlDoorDoorNo,
)
from .root_type_for_xml_cap_remote_control_door_remote_control_door_password import (
    RootTypeForXMLCapRemoteControlDoorRemoteControlDoorPassword,
)
from .root_type_for_xml_device_info import RootTypeForXMLDeviceInfo
from .root_type_for_xml_device_info_device_info import RootTypeForXMLDeviceInfoDeviceInfo
from .root_type_for_xml_device_info_device_info_detail_abnormal_status import (
    RootTypeForXMLDeviceInfoDeviceInfoDetailAbnormalStatus,
)
from .root_type_for_xml_device_info_device_info_detail_abnormal_status_ethernet_broken import (
    RootTypeForXMLDeviceInfoDeviceInfoDetailAbnormalStatusEthernetBroken,
)
from .root_type_for_xml_device_info_device_info_detail_abnormal_status_hard_disk_error import (
    RootTypeForXMLDeviceInfoDeviceInfoDetailAbnormalStatusHardDiskError,
)
from .root_type_for_xml_device_info_device_info_detail_abnormal_status_hard_disk_full import (
    RootTypeForXMLDeviceInfoDeviceInfoDetailAbnormalStatusHardDiskFull,
)
from .root_type_for_xml_device_info_device_info_detail_abnormal_status_illegal_access import (
    RootTypeForXMLDeviceInfoDeviceInfoDetailAbnormalStatusIllegalAccess,
)
from .root_type_for_xml_device_info_device_info_detail_abnormal_status_ipaddr_conflict import (
    RootTypeForXMLDeviceInfoDeviceInfoDetailAbnormalStatusIpaddrConflict,
)
from .root_type_for_xml_device_info_device_info_detail_abnormal_status_raid_logic_disk_error import (
    RootTypeForXMLDeviceInfoDeviceInfoDetailAbnormalStatusRaidLogicDiskError,
)
from .root_type_for_xml_device_info_device_info_detail_abnormal_status_record_error import (
    RootTypeForXMLDeviceInfoDeviceInfoDetailAbnormalStatusRecordError,
)
from .root_type_for_xml_device_info_device_info_detail_abnormal_status_spare_work_device_error import (
    RootTypeForXMLDeviceInfoDeviceInfoDetailAbnormalStatusSpareWorkDeviceError,
)
from .root_type_for_xml_device_info_device_info_dock_station import RootTypeForXMLDeviceInfoDeviceInfoDockStation
from .root_type_for_xml_device_info_device_info_dock_station_platform import (
    RootTypeForXMLDeviceInfoDeviceInfoDockStationPlatform,
)
from .root_type_for_xml_device_info_device_info_is_reset_device_language import (
    RootTypeForXMLDeviceInfoDeviceInfoIsResetDeviceLanguage,
)
from .root_type_for_xml_device_info_device_info_r3_version import RootTypeForXMLDeviceInfoDeviceInfoR3Version
from .root_type_for_xml_device_info_device_info_rx_version import RootTypeForXMLDeviceInfoDeviceInfoRxVersion
from .root_type_for_xml_device_info_device_info_uid_lamp_recognition import (
    RootTypeForXMLDeviceInfoDeviceInfoUIDLampRecognition,
)
from .root_type_for_xml_device_info_device_info_zig_bee_version import RootTypeForXMLDeviceInfoDeviceInfoZigBeeVersion
from .root_type_for_xml_network_interface import RootTypeForXMLNetworkInterface
from .root_type_for_xml_network_interface_list import RootTypeForXMLNetworkInterfaceList
from .root_type_for_xml_network_interface_list_network_interface_list import (
    RootTypeForXMLNetworkInterfaceListNetworkInterfaceList,
)
from .root_type_for_xml_network_interface_network_interface import RootTypeForXMLNetworkInterfaceNetworkInterface
from .root_type_for_xml_network_interface_network_interface_active_multicast import (
    RootTypeForXMLNetworkInterfaceNetworkInterfaceActiveMulticast,
)
from .root_type_for_xml_network_interface_network_interface_active_multicast_port import (
    RootTypeForXMLNetworkInterfaceNetworkInterfaceActiveMulticastPort,
)
from .root_type_for_xml_network_interface_network_interface_active_multicast_stream_id import (
    RootTypeForXMLNetworkInterfaceNetworkInterfaceActiveMulticastStreamID,
)
from .root_type_for_xml_network_interface_network_interface_ethernet_port_list import (
    RootTypeForXMLNetworkInterfaceNetworkInterfaceEthernetPortList,
)
from .root_type_for_xml_network_interface_network_interface_ethernet_port_list_ethernet_port import (
    RootTypeForXMLNetworkInterfaceNetworkInterfaceEthernetPortListEthernetPort,
)
from .root_type_for_xml_network_interface_network_interface_mac_address import (
    RootTypeForXMLNetworkInterfaceNetworkInterfaceMacAddress,
)
from .root_type_for_xml_remote_control_door import RootTypeForXMLRemoteControlDoor
from .root_type_for_xml_remote_control_door_remote_control_door import RootTypeForXMLRemoteControlDoorRemoteControlDoor
from .root_type_for_xml_response_status import RootTypeForXMLResponseStatus
from .root_type_for_xml_response_status_authentication_failed import RootTypeForXMLResponseStatusAuthenticationFailed
from .root_type_for_xml_response_status_authentication_failed_response_status import (
    RootTypeForXMLResponseStatusAuthenticationFailedResponseStatus,
)
from .root_type_for_xml_response_status_response_status import RootTypeForXMLResponseStatusResponseStatus
from .root_type_for_xml_session_login import RootTypeForXMLSessionLogin
from .root_type_for_xml_session_login_cap import RootTypeForXMLSessionLoginCap
from .root_type_for_xml_session_login_cap_session_login_cap import RootTypeForXMLSessionLoginCapSessionLoginCap
from .root_type_for_xml_session_login_response import RootTypeForXMLSessionLoginResponse
from .root_type_for_xml_session_login_response_session_login import RootTypeForXMLSessionLoginResponseSessionLogin
from .root_type_for_xml_session_login_session_login import RootTypeForXMLSessionLoginSessionLogin
from .root_type_for_xml_streaming_channel import RootTypeForXMLStreamingChannel
from .root_type_for_xml_streaming_channel_audio import RootTypeForXMLStreamingChannelAudio
from .root_type_for_xml_streaming_channel_list import RootTypeForXMLStreamingChannelList
from .root_type_for_xml_streaming_channel_list_streaming_channel_list import (
    RootTypeForXMLStreamingChannelListStreamingChannelList,
)
from .root_type_for_xml_streaming_channel_transport import RootTypeForXMLStreamingChannelTransport
from .root_type_for_xml_streaming_channel_transport_control_protocol_list import (
    RootTypeForXMLStreamingChannelTransportControlProtocolList,
)
from .root_type_for_xml_streaming_channel_transport_control_protocol_list_control_protocol_item import (
    RootTypeForXMLStreamingChannelTransportControlProtocolListControlProtocolItem,
)
from .root_type_for_xml_streaming_channel_transport_security import RootTypeForXMLStreamingChannelTransportSecurity
from .root_type_for_xml_streaming_channel_video import RootTypeForXMLStreamingChannelVideo
from .root_type_for_xml_two_way_audio_channel import RootTypeForXMLTwoWayAudioChannel
from .root_type_for_xml_two_way_audio_channel_list import RootTypeForXMLTwoWayAudioChannelList
from .root_type_for_xml_two_way_audio_channel_list_two_way_audio_channel_list import (
    RootTypeForXMLTwoWayAudioChannelListTwoWayAudioChannelList,
)
from .root_type_for_xml_two_way_audio_channel_two_way_audio_channel import (
    RootTypeForXMLTwoWayAudioChannelTwoWayAudioChannel,
)
from .root_type_for_xml_two_way_audio_channel_two_way_audio_channel_associate_video_inputs import (
    RootTypeForXMLTwoWayAudioChannelTwoWayAudioChannelAssociateVideoInputs,
)
from .root_type_for_xml_two_way_audio_channel_two_way_audio_channel_associate_video_inputs_enabled import (
    RootTypeForXMLTwoWayAudioChannelTwoWayAudioChannelAssociateVideoInputsEnabled,
)
from .root_type_for_xml_two_way_audio_channel_two_way_audio_channel_associate_video_inputs_video_input_channel_list import (
    RootTypeForXMLTwoWayAudioChannelTwoWayAudioChannelAssociateVideoInputsVideoInputChannelList,
)
from .root_type_for_xml_two_way_audio_channel_two_way_audio_channel_associate_video_inputs_video_input_channel_list_video_input_channel_id import (
    RootTypeForXMLTwoWayAudioChannelTwoWayAudioChannelAssociateVideoInputsVideoInputChannelListVideoInputChannelID,
)
from .root_type_for_xml_two_way_audio_channel_two_way_audio_channel_audio_bit_rate import (
    RootTypeForXMLTwoWayAudioChannelTwoWayAudioChannelAudioBitRate,
)
from .root_type_for_xml_two_way_audio_channel_two_way_audio_channel_audio_compression_type import (
    RootTypeForXMLTwoWayAudioChannelTwoWayAudioChannelAudioCompressionType,
)
from .root_type_for_xml_two_way_audio_channel_two_way_audio_channel_audio_inbound_compression_type import (
    RootTypeForXMLTwoWayAudioChannelTwoWayAudioChannelAudioInboundCompressionType,
)
from .root_type_for_xml_two_way_audio_channel_two_way_audio_channel_audio_input_type import (
    RootTypeForXMLTwoWayAudioChannelTwoWayAudioChannelAudioInputType,
)
from .root_type_for_xml_two_way_audio_channel_two_way_audio_channel_enabled import (
    RootTypeForXMLTwoWayAudioChannelTwoWayAudioChannelEnabled,
)
from .root_type_for_xml_two_way_audio_channel_two_way_audio_channel_id import (
    RootTypeForXMLTwoWayAudioChannelTwoWayAudioChannelId,
)
from .root_type_for_xml_two_way_audio_channel_two_way_audio_channel_line_out_forbidden import (
    RootTypeForXMLTwoWayAudioChannelTwoWayAudioChannelLineOutForbidden,
)
from .root_type_for_xml_two_way_audio_channel_two_way_audio_channel_mic_in_forbidden import (
    RootTypeForXMLTwoWayAudioChannelTwoWayAudioChannelMicInForbidden,
)
from .root_type_for_xml_two_way_audio_channel_two_way_audio_channel_microphone_volume import (
    RootTypeForXMLTwoWayAudioChannelTwoWayAudioChannelMicrophoneVolume,
)
from .root_type_for_xml_two_way_audio_channel_two_way_audio_channel_noisereduce import (
    RootTypeForXMLTwoWayAudioChannelTwoWayAudioChannelNoisereduce,
)
from .root_type_for_xml_two_way_audio_channel_two_way_audio_channel_speaker_volume import (
    RootTypeForXMLTwoWayAudioChannelTwoWayAudioChannelSpeakerVolume,
)
from .root_type_for_xml_two_way_audio_session import RootTypeForXMLTwoWayAudioSession
from .root_type_for_xml_two_way_audio_session_two_way_audio_session import (
    RootTypeForXMLTwoWayAudioSessionTwoWayAudioSession,
)
from .root_type_for_xml_user_check import RootTypeForXMLUserCheck
from .root_type_for_xml_user_check_user_check import RootTypeForXMLUserCheckUserCheck
from .root_type_for_xml_video_input_channel import RootTypeForXMLVideoInputChannel
from .root_type_for_xml_video_input_channel_list import RootTypeForXMLVideoInputChannelList
from .root_type_for_xml_video_input_channel_list_video_input_channel_list import (
    RootTypeForXMLVideoInputChannelListVideoInputChannelList,
)
from .root_type_for_xml_video_input_channel_video_input_channel import RootTypeForXMLVideoInputChannelVideoInputChannel
from .root_type_for_xml_video_input_channel_video_input_channel_id import (
    RootTypeForXMLVideoInputChannelVideoInputChannelId,
)
from .root_type_for_xml_video_input_channel_video_input_channel_input_port import (
    RootTypeForXMLVideoInputChannelVideoInputChannelInputPort,
)
from .root_type_for_xml_video_input_channel_video_input_channel_name import (
    RootTypeForXMLVideoInputChannelVideoInputChannelName,
)
from .root_type_for_xml_video_input_channel_video_input_channel_port_type import (
    RootTypeForXMLVideoInputChannelVideoInputChannelPortType,
)
from .root_type_for_xml_video_input_channel_video_input_channel_res_desc import (
    RootTypeForXMLVideoInputChannelVideoInputChannelResDesc,
)
from .root_type_for_xml_video_input_channel_video_input_channel_video_format import (
    RootTypeForXMLVideoInputChannelVideoInputChannelVideoFormat,
)
from .root_type_for_xml_video_input_channel_video_input_channel_video_input_enabled import (
    RootTypeForXMLVideoInputChannelVideoInputChannelVideoInputEnabled,
)

__all__ = (
    "RootTypeForCallStatus",
    "RootTypeForCallStatusCallStatus",
    "RootTypeForJSONCapCallStatus",
    "RootTypeForJSONCapCallStatusCallStatus",
    "RootTypeForJSONCapCallStatusCallStatusStatus",
    "RootTypeForJSONResponseStatus",
    "RootTypeForXMLCapAccessControl",
    "RootTypeForXMLCapAccessControlAccessControl",
    "RootTypeForXMLCapAccessControlAccessControlEmployeeNoInfo",
    "RootTypeForXMLCapAccessControlAccessControlEmployeeNoInfoCharacterType",
    "RootTypeForXMLCapAccessControlAccessControlEmployeeNoInfoEmployeeNo",
    "RootTypeForXMLCapAccessControlAccessControlEmployeeNoInfoIsSupportCompress",
    "RootTypeForXMLCapAccessControlAccessControlFactoryReset",
    "RootTypeForXMLCapAccessControlAccessControlFactoryResetMode",
    "RootTypeForXMLCapAccessControlAccessControlIsSupportAcsCfg",
    "RootTypeForXMLCapAccessControlAccessControlIsSupportAcsEvent",
    "RootTypeForXMLCapAccessControlAccessControlIsSupportAcsEventTotalNum",
    "RootTypeForXMLCapAccessControlAccessControlIsSupportAcsWorkStatus",
    "RootTypeForXMLCapAccessControlAccessControlIsSupportAntiSneakCfg",
    "RootTypeForXMLCapAccessControlAccessControlIsSupportAttendanceHolidayGroup",
    "RootTypeForXMLCapAccessControlAccessControlIsSupportAttendanceHolidayPlan",
    "RootTypeForXMLCapAccessControlAccessControlIsSupportAttendanceRule",
    "RootTypeForXMLCapAccessControlAccessControlIsSupportAttendanceStatusModeCfg",
    "RootTypeForXMLCapAccessControlAccessControlIsSupportAttendanceStatusRuleCfg",
    "RootTypeForXMLCapAccessControlAccessControlIsSupportAuthCodeInfo",
    "RootTypeForXMLCapAccessControlAccessControlIsSupportCaptureCardInfo",
    "RootTypeForXMLCapAccessControlAccessControlIsSupportCaptureFace",
    "RootTypeForXMLCapAccessControlAccessControlIsSupportCaptureFingerPrint",
    "RootTypeForXMLCapAccessControlAccessControlIsSupportCaptureIDInfo",
    "RootTypeForXMLCapAccessControlAccessControlIsSupportCaptureInfraredFace",
    "RootTypeForXMLCapAccessControlAccessControlIsSupportCapturePresetParam",
    "RootTypeForXMLCapAccessControlAccessControlIsSupportCaptureRule",
    "RootTypeForXMLCapAccessControlAccessControlIsSupportCardOperations",
    "RootTypeForXMLCapAccessControlAccessControlIsSupportCardReaderAntiSneakCfg",
    "RootTypeForXMLCapAccessControlAccessControlIsSupportCardReaderCfg",
    "RootTypeForXMLCapAccessControlAccessControlIsSupportCardReaderPlan",
    "RootTypeForXMLCapAccessControlAccessControlIsSupportCardRightHolidayPlanCfg",
    "RootTypeForXMLCapAccessControlAccessControlIsSupportCardRightWeekPlanCfg",
    "RootTypeForXMLCapAccessControlAccessControlIsSupportChannelControllerAlarmLinkage",
    "RootTypeForXMLCapAccessControlAccessControlIsSupportChannelControllerAlarmOut",
    "RootTypeForXMLCapAccessControlAccessControlIsSupportChannelControllerAlarmOutControl",
    "RootTypeForXMLCapAccessControlAccessControlIsSupportChannelControllerCfg",
    "RootTypeForXMLCapAccessControlAccessControlIsSupportChannelControllerTypeCfg",
    "RootTypeForXMLCapAccessControlAccessControlIsSupportClearAntiSneak",
    "RootTypeForXMLCapAccessControlAccessControlIsSupportClearAntiSneakCfg",
    "RootTypeForXMLCapAccessControlAccessControlIsSupportClearCardRecord",
    "RootTypeForXMLCapAccessControlAccessControlIsSupportClearEventCardLinkageCfg",
    "RootTypeForXMLCapAccessControlAccessControlIsSupportClearGroupCfg",
    "RootTypeForXMLCapAccessControlAccessControlIsSupportClearPlansCfg",
    "RootTypeForXMLCapAccessControlAccessControlIsSupportClearSubmarineBack",
    "RootTypeForXMLCapAccessControlAccessControlIsSupportDepartmentParam",
    "RootTypeForXMLCapAccessControlAccessControlIsSupportDeployInfoItem",
    "RootTypeForXMLCapAccessControlAccessControlIsSupportDoorCfg",
    "RootTypeForXMLCapAccessControlAccessControlIsSupportDoorStatusHolidayGroupCfg",
    "RootTypeForXMLCapAccessControlAccessControlIsSupportDoorStatusHolidayPlanCfg",
    "RootTypeForXMLCapAccessControlAccessControlIsSupportDoorStatusPlan",
    "RootTypeForXMLCapAccessControlAccessControlIsSupportDoorStatusPlanTemplate",
    "RootTypeForXMLCapAccessControlAccessControlIsSupportDoorStatusWeekPlanCfg",
    "RootTypeForXMLCapAccessControlAccessControlIsSupportEventCardLinkageCfg",
    "RootTypeForXMLCapAccessControlAccessControlIsSupportEventCardNoList",
    "RootTypeForXMLCapAccessControlAccessControlIsSupportEventOptimizationCfg",
    "RootTypeForXMLCapAccessControlAccessControlIsSupportFaceRecognizeMode",
    "RootTypeForXMLCapAccessControlAccessControlIsSupportFingerPrintCfg",
    "RootTypeForXMLCapAccessControlAccessControlIsSupportFingerPrintDelete",
    "RootTypeForXMLCapAccessControlAccessControlIsSupportGateDialAndInfo",
    "RootTypeForXMLCapAccessControlAccessControlIsSupportGateIRStatus",
    "RootTypeForXMLCapAccessControlAccessControlIsSupportGateRelatedPartsStatus",
    "RootTypeForXMLCapAccessControlAccessControlIsSupportGateStatus",
    "RootTypeForXMLCapAccessControlAccessControlIsSupportGroupCfg",
    "RootTypeForXMLCapAccessControlAccessControlIsSupportIdentityTerminal",
    "RootTypeForXMLCapAccessControlAccessControlIsSupportLadderControlRelay",
    "RootTypeForXMLCapAccessControlAccessControlIsSupportLogModeCfg",
    "RootTypeForXMLCapAccessControlAccessControlIsSupportM1CardEncryptCfg",
    "RootTypeForXMLCapAccessControlAccessControlIsSupportModuleStatus",
    "RootTypeForXMLCapAccessControlAccessControlIsSupportMultiCardCfg",
    "RootTypeForXMLCapAccessControlAccessControlIsSupportMultiDoorInterLockCfg",
    "RootTypeForXMLCapAccessControlAccessControlIsSupportOfflineCapture",
    "RootTypeForXMLCapAccessControlAccessControlIsSupportOrdinaryClass",
    "RootTypeForXMLCapAccessControlAccessControlIsSupportOSDPModify",
    "RootTypeForXMLCapAccessControlAccessControlIsSupportOSDPStatus",
    "RootTypeForXMLCapAccessControlAccessControlIsSupportPhoneDoorRightCfg",
    "RootTypeForXMLCapAccessControlAccessControlIsSupportReaderAcrossHost",
    "RootTypeForXMLCapAccessControlAccessControlIsSupportRemoteControlBuzzer",
    "RootTypeForXMLCapAccessControlAccessControlIsSupportRemoteControlDoor",
    "RootTypeForXMLCapAccessControlAccessControlIsSupportRemoteControlPWCfg",
    "RootTypeForXMLCapAccessControlAccessControlIsSupportRemoteControlPWChcek",
    "RootTypeForXMLCapAccessControlAccessControlIsSupportRightControllerAudio",
    "RootTypeForXMLCapAccessControlAccessControlIsSupportSchedulePlan",
    "RootTypeForXMLCapAccessControlAccessControlIsSupportServerDevice",
    "RootTypeForXMLCapAccessControlAccessControlIsSupportSmsRelativeParam",
    "RootTypeForXMLCapAccessControlAccessControlIsSupportSNAPConfig",
    "RootTypeForXMLCapAccessControlAccessControlIsSupportStartReaderInfo",
    "RootTypeForXMLCapAccessControlAccessControlIsSupportSubmarineBack",
    "RootTypeForXMLCapAccessControlAccessControlIsSupportSubmarineBackHostInfo",
    "RootTypeForXMLCapAccessControlAccessControlIsSupportSubmarineBackMode",
    "RootTypeForXMLCapAccessControlAccessControlIsSupportSubmarineBackReader",
    "RootTypeForXMLCapAccessControlAccessControlIsSupportUSBManage",
    "RootTypeForXMLCapAccessControlAccessControlIsSupportUserRightHolidayGroupCfg",
    "RootTypeForXMLCapAccessControlAccessControlIsSupportUserRightPlanTemplate",
    "RootTypeForXMLCapAccessControlAccessControlIsSupportVerifyHolidayGroupCfg",
    "RootTypeForXMLCapAccessControlAccessControlIsSupportVerifyHolidayPlanCfg",
    "RootTypeForXMLCapAccessControlAccessControlIsSupportVerifyPlanTemplate",
    "RootTypeForXMLCapAccessControlAccessControlIsSupportVerifyWeekPlanCfg",
    "RootTypeForXMLCapAccessControlAccessControlIsSupportWiegandCfg",
    "RootTypeForXMLCapAccessControlAccessControlIsSupportWiegandRuleCfg",
    "RootTypeForXMLCapAccessControlAccessControlIsSupportWorkingClass",
    "RootTypeForXMLCapAccessControlAccessControlLocalController",
    "RootTypeForXMLCapAccessControlAccessControlLocalControllerIsSupportLocalControllerControl",
    "RootTypeForXMLCapAccessControlAccessControlLocalControllerIsSupportLocalControllerManage",
    "RootTypeForXMLCapRemoteControlDoor",
    "RootTypeForXMLCapRemoteControlDoorRemoteControlDoor",
    "RootTypeForXMLCapRemoteControlDoorRemoteControlDoorCmd",
    "RootTypeForXMLCapRemoteControlDoorRemoteControlDoorDoorNo",
    "RootTypeForXMLCapRemoteControlDoorRemoteControlDoorPassword",
    "RootTypeForXMLDeviceInfo",
    "RootTypeForXMLDeviceInfoDeviceInfo",
    "RootTypeForXMLDeviceInfoDeviceInfoDetailAbnormalStatus",
    "RootTypeForXMLDeviceInfoDeviceInfoDetailAbnormalStatusEthernetBroken",
    "RootTypeForXMLDeviceInfoDeviceInfoDetailAbnormalStatusHardDiskError",
    "RootTypeForXMLDeviceInfoDeviceInfoDetailAbnormalStatusHardDiskFull",
    "RootTypeForXMLDeviceInfoDeviceInfoDetailAbnormalStatusIllegalAccess",
    "RootTypeForXMLDeviceInfoDeviceInfoDetailAbnormalStatusIpaddrConflict",
    "RootTypeForXMLDeviceInfoDeviceInfoDetailAbnormalStatusRaidLogicDiskError",
    "RootTypeForXMLDeviceInfoDeviceInfoDetailAbnormalStatusRecordError",
    "RootTypeForXMLDeviceInfoDeviceInfoDetailAbnormalStatusSpareWorkDeviceError",
    "RootTypeForXMLDeviceInfoDeviceInfoDockStation",
    "RootTypeForXMLDeviceInfoDeviceInfoDockStationPlatform",
    "RootTypeForXMLDeviceInfoDeviceInfoIsResetDeviceLanguage",
    "RootTypeForXMLDeviceInfoDeviceInfoR3Version",
    "RootTypeForXMLDeviceInfoDeviceInfoRxVersion",
    "RootTypeForXMLDeviceInfoDeviceInfoUIDLampRecognition",
    "RootTypeForXMLDeviceInfoDeviceInfoZigBeeVersion",
    "RootTypeForXMLNetworkInterface",
    "RootTypeForXMLNetworkInterfaceList",
    "RootTypeForXMLNetworkInterfaceListNetworkInterfaceList",
    "RootTypeForXMLNetworkInterfaceNetworkInterface",
    "RootTypeForXMLNetworkInterfaceNetworkInterfaceActiveMulticast",
    "RootTypeForXMLNetworkInterfaceNetworkInterfaceActiveMulticastPort",
    "RootTypeForXMLNetworkInterfaceNetworkInterfaceActiveMulticastStreamID",
    "RootTypeForXMLNetworkInterfaceNetworkInterfaceEthernetPortList",
    "RootTypeForXMLNetworkInterfaceNetworkInterfaceEthernetPortListEthernetPort",
    "RootTypeForXMLNetworkInterfaceNetworkInterfaceMacAddress",
    "RootTypeForXMLRemoteControlDoor",
    "RootTypeForXMLRemoteControlDoorRemoteControlDoor",
    "RootTypeForXMLResponseStatus",
    "RootTypeForXMLResponseStatusAuthenticationFailed",
    "RootTypeForXMLResponseStatusAuthenticationFailedResponseStatus",
    "RootTypeForXMLResponseStatusResponseStatus",
    "RootTypeForXMLSessionLogin",
    "RootTypeForXMLSessionLoginCap",
    "RootTypeForXMLSessionLoginCapSessionLoginCap",
    "RootTypeForXMLSessionLoginResponse",
    "RootTypeForXMLSessionLoginResponseSessionLogin",
    "RootTypeForXMLSessionLoginSessionLogin",
    "RootTypeForXMLStreamingChannel",
    "RootTypeForXMLStreamingChannelAudio",
    "RootTypeForXMLStreamingChannelList",
    "RootTypeForXMLStreamingChannelListStreamingChannelList",
    "RootTypeForXMLStreamingChannelTransport",
    "RootTypeForXMLStreamingChannelTransportControlProtocolList",
    "RootTypeForXMLStreamingChannelTransportControlProtocolListControlProtocolItem",
    "RootTypeForXMLStreamingChannelTransportSecurity",
    "RootTypeForXMLStreamingChannelVideo",
    "RootTypeForXMLTwoWayAudioChannel",
    "RootTypeForXMLTwoWayAudioChannelList",
    "RootTypeForXMLTwoWayAudioChannelListTwoWayAudioChannelList",
    "RootTypeForXMLTwoWayAudioChannelTwoWayAudioChannel",
    "RootTypeForXMLTwoWayAudioChannelTwoWayAudioChannelAssociateVideoInputs",
    "RootTypeForXMLTwoWayAudioChannelTwoWayAudioChannelAssociateVideoInputsEnabled",
    "RootTypeForXMLTwoWayAudioChannelTwoWayAudioChannelAssociateVideoInputsVideoInputChannelList",
    "RootTypeForXMLTwoWayAudioChannelTwoWayAudioChannelAssociateVideoInputsVideoInputChannelListVideoInputChannelID",
    "RootTypeForXMLTwoWayAudioChannelTwoWayAudioChannelAudioBitRate",
    "RootTypeForXMLTwoWayAudioChannelTwoWayAudioChannelAudioCompressionType",
    "RootTypeForXMLTwoWayAudioChannelTwoWayAudioChannelAudioInboundCompressionType",
    "RootTypeForXMLTwoWayAudioChannelTwoWayAudioChannelAudioInputType",
    "RootTypeForXMLTwoWayAudioChannelTwoWayAudioChannelEnabled",
    "RootTypeForXMLTwoWayAudioChannelTwoWayAudioChannelId",
    "RootTypeForXMLTwoWayAudioChannelTwoWayAudioChannelLineOutForbidden",
    "RootTypeForXMLTwoWayAudioChannelTwoWayAudioChannelMicInForbidden",
    "RootTypeForXMLTwoWayAudioChannelTwoWayAudioChannelMicrophoneVolume",
    "RootTypeForXMLTwoWayAudioChannelTwoWayAudioChannelNoisereduce",
    "RootTypeForXMLTwoWayAudioChannelTwoWayAudioChannelSpeakerVolume",
    "RootTypeForXMLTwoWayAudioSession",
    "RootTypeForXMLTwoWayAudioSessionTwoWayAudioSession",
    "RootTypeForXMLUserCheck",
    "RootTypeForXMLUserCheckUserCheck",
    "RootTypeForXMLVideoInputChannel",
    "RootTypeForXMLVideoInputChannelList",
    "RootTypeForXMLVideoInputChannelListVideoInputChannelList",
    "RootTypeForXMLVideoInputChannelVideoInputChannel",
    "RootTypeForXMLVideoInputChannelVideoInputChannelId",
    "RootTypeForXMLVideoInputChannelVideoInputChannelInputPort",
    "RootTypeForXMLVideoInputChannelVideoInputChannelName",
    "RootTypeForXMLVideoInputChannelVideoInputChannelPortType",
    "RootTypeForXMLVideoInputChannelVideoInputChannelResDesc",
    "RootTypeForXMLVideoInputChannelVideoInputChannelVideoFormat",
    "RootTypeForXMLVideoInputChannelVideoInputChannelVideoInputEnabled",
)
